from rapidata.rapidata_client.settings.alert_on_fast_response import AlertOnFastResponseSetting
from rapidata.rapidata_client.settings.translation_behaviour import TranslationBehaviourSetting
from rapidata.rapidata_client.settings.free_text_minimum_characters import FreeTextMinimumCharactersSetting
from rapidata.rapidata_client.settings.no_shuffle import NoShuffleSetting
from rapidata.rapidata_client.settings.play_video_until_the_end import PlayVideoUntilTheEndSetting
from rapidata.rapidata_client.settings.allow_neither_both import AllowNeitherBothSetting
from rapidata.rapidata_client.settings.swap_context_instruction import SwapContextInstructionSetting
from rapidata.rapidata_client.settings.mute_video import MuteVideoSetting


class RapidataSettings:
    """
    Container class for all setting factory functions

    Settings can be added to an order to determine the behaviour of the task.

    Attributes:
        AlertOnFastResponse (AlertOnFastResponseSetting): Gives an alert as a pop up on the UI when the response time is less than the milliseconds.
        TranslationBehaviour (TranslationBehaviourSetting): Defines what's the behaviour of the translation in the UI.
        FreeTextMinimumCharacters (FreeTextMinimumCharactersSetting): Only for free text tasks. Set the minimum number of characters a user has to type.
        NoShuffle (NoShuffleSetting): Only for classification and compare tasks. If true, the order of the categories / images will not be shuffled and presented in the same order as specified.
        PlayVideoUntilTheEnd (PlayVideoUntilTheEndSetting): Allows users to only answer once the video has finished playing.
        AllowNeitherBoth (AllowNeitherBothSetting): Only for compare tasks. If true, the users will be able to select neither or both instead of exclusively one of the options.
        SwapContextInstruction (SwapContextInstructionSetting): Swap the place of the context and instruction.
        MuteVideo (MuteVideoSetting): Mute the video.

    Example:
        ```python
        from rapidata import FreeTextMinimumCharactersSetting
        settings=[FreeTextMinimumCharactersSetting(10)]
        ```

        This can be used in a free text order to set the minimum number of characters required to submit the task.
    """

    AlertOnFastResponse = AlertOnFastResponseSetting
    TranslationBehaviour = TranslationBehaviourSetting
    FreeTextMinimumCharacters = FreeTextMinimumCharactersSetting
    NoShuffle = NoShuffleSetting
    PlayVideoUntilTheEnd = PlayVideoUntilTheEndSetting
    AllowNeitherBoth = AllowNeitherBothSetting
    SwapContextInstruction = SwapContextInstructionSetting
    MuteVideo = MuteVideoSetting

    def __str__(self) -> str:
        return f"RapidataSettings(AlertOnFastResponse={self.AlertOnFastResponse}, TranslationBehaviour={self.TranslationBehaviour}, FreeTextMinimumCharacters={self.FreeTextMinimumCharacters}, NoShuffle={self.NoShuffle}, PlayVideoUntilTheEnd={self.PlayVideoUntilTheEnd}, AllowNeitherBoth={self.AllowNeitherBoth}, SwapContextInstruction={self.SwapContextInstruction}, MuteVideo={self.MuteVideo})"

    def __repr__(self) -> str:
        return self.__str__()



from __future__ import annotations

import warnings

from rapidata.rapidata_client.settings._rapidata_setting import RapidataSetting


class MuteVideoSetting(RapidataSetting):
    """
    Mute the video. If this setting is not supplied, the video will not be muted.

    Args:
        value (bool): Whether to mute the video. Defaults to True.
    """

    def __init__(self, value: bool = True):
        if not isinstance(value, bool):
            raise ValueError("The value must be a boolean.")
        super().__init__(key="mute_video_asset", value=value)


class MuteVideo(MuteVideoSetting):
    """Deprecated: Use :class:`MuteVideoSetting` instead."""

    def __init__(self, *args, **kwargs):
        warnings.warn(
            "MuteVideo is deprecated, use MuteVideoSetting instead",
            DeprecationWarning,
            stacklevel=2,
        )
        super().__init__(*args, **kwargs)



from __future__ import annotations

import warnings

from rapidata.rapidata_client.settings._rapidata_setting import RapidataSetting


class NoShuffleSetting(RapidataSetting):
    """
    Only for classification and compare tasks. If true, the order of the categories / images will not be shuffled and presented in the same order as specified.

    If this is not added to the order, the shuffling will be active.

    Args:
        value (bool, optional): Whether to disable shuffling. Defaults to True for function call.
    """

    def __init__(self, value: bool = True):
        if not isinstance(value, bool):
            raise ValueError("The value must be a boolean.")

        super().__init__(key="no_shuffle", value=value)


class NoShuffle(NoShuffleSetting):
    """Deprecated: Use :class:`NoShuffleSetting` instead."""

    def __init__(self, *args, **kwargs):
        warnings.warn(
            "NoShuffle is deprecated, use NoShuffleSetting instead",
            DeprecationWarning,
            stacklevel=2,
        )
        super().__init__(*args, **kwargs)



from rapidata.service.services.asset_service import AssetService
from rapidata.service.services.audience_service import AudienceService
from rapidata.service.services.campaign_service import CampaignService
from rapidata.service.services.dataset_service import DatasetService
from rapidata.service.services.flow_service import FlowService
from rapidata.service.services.leaderboard_service import LeaderboardService
from rapidata.service.services.order_service import OrderService
from rapidata.service.services.pipeline_service import PipelineService
from rapidata.service.services.rapid_service import RapidService
from rapidata.service.services.validation_service import ValidationService
from rapidata.service.services.workflow_service import WorkflowService

__all__ = [
    "AssetService",
    "AudienceService",
    "CampaignService",
    "DatasetService",
    "FlowService",
    "LeaderboardService",
    "OrderService",
    "PipelineService",
    "RapidService",
    "ValidationService",
    "WorkflowService",
]



from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from rapidata.api_client.api.flow_api import FlowApi
    from rapidata.api_client.api.ranking_flow_api import RankingFlowApi
    from rapidata.api_client.api.ranking_flow_item_api import RankingFlowItemApi
    from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient


class FlowService:
    def __init__(self, api_client: RapidataApiClient) -> None:
        self._api_client = api_client
        self._flow_api: FlowApi | None = None
        self._ranking_flow_api: RankingFlowApi | None = None
        self._ranking_flow_item_api: RankingFlowItemApi | None = None

    @property
    def flow_api(self) -> FlowApi:
        if self._flow_api is None:
            from rapidata.api_client.api.flow_api import FlowApi
            self._flow_api = FlowApi(self._api_client)
        return self._flow_api

    @property
    def ranking_flow_api(self) -> RankingFlowApi:
        if self._ranking_flow_api is None:
            from rapidata.api_client.api.ranking_flow_api import RankingFlowApi
            self._ranking_flow_api = RankingFlowApi(self._api_client)
        return self._ranking_flow_api

    @property
    def ranking_flow_item_api(self) -> RankingFlowItemApi:
        if self._ranking_flow_item_api is None:
            from rapidata.api_client.api.ranking_flow_item_api import RankingFlowItemApi
            self._ranking_flow_item_api = RankingFlowItemApi(self._api_client)
        return self._ranking_flow_item_api



from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from rapidata.api_client.api.dataset_api import DatasetApi
    from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient


class DatasetService:
    def __init__(self, api_client: RapidataApiClient) -> None:
        self._api_client = api_client
        self._dataset_api: DatasetApi | None = None

    @property
    def dataset_api(self) -> DatasetApi:
        if self._dataset_api is None:
            from rapidata.api_client.api.dataset_api import DatasetApi
            self._dataset_api = DatasetApi(self._api_client)
        return self._dataset_api



from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from rapidata.api_client.api.leaderboard_api import LeaderboardApi
    from rapidata.api_client.api.benchmark_api import BenchmarkApi
    from rapidata.api_client.api.participant_api import ParticipantApi
    from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient


class LeaderboardService:
    def __init__(self, api_client: RapidataApiClient) -> None:
        self._api_client = api_client
        self._leaderboard_api: LeaderboardApi | None = None
        self._benchmark_api: BenchmarkApi | None = None
        self._participant_api: ParticipantApi | None = None

    @property
    def leaderboard_api(self) -> LeaderboardApi:
        if self._leaderboard_api is None:
            from rapidata.api_client.api.leaderboard_api import LeaderboardApi
            self._leaderboard_api = LeaderboardApi(self._api_client)
        return self._leaderboard_api

    @property
    def benchmark_api(self) -> BenchmarkApi:
        if self._benchmark_api is None:
            from rapidata.api_client.api.benchmark_api import BenchmarkApi
            self._benchmark_api = BenchmarkApi(self._api_client)
        return self._benchmark_api

    @property
    def participant_api(self) -> ParticipantApi:
        if self._participant_api is None:
            from rapidata.api_client.api.participant_api import ParticipantApi
            self._participant_api = ParticipantApi(self._api_client)
        return self._participant_api



from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from rapidata.api_client.api.customer_rapid_api import CustomerRapidApi
    from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient


class RapidService:
    def __init__(self, api_client: RapidataApiClient) -> None:
        self._api_client = api_client
        self._rapid_api: CustomerRapidApi | None = None

    @property
    def rapid_api(self) -> CustomerRapidApi:
        if self._rapid_api is None:
            from rapidata.api_client.api.customer_rapid_api import CustomerRapidApi
            self._rapid_api = CustomerRapidApi(self._api_client)
        return self._rapid_api



# coding: utf-8

"""
    Rapidata Asset API

    The API for the Rapidata Asset service

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import Optional
from typing_extensions import Annotated
from rapidata.api_client.models.client_model import ClientModel
from rapidata.api_client.models.create_client_model import CreateClientModel
from rapidata.api_client.models.create_customer_client_result import CreateCustomerClientResult
from rapidata.api_client.models.dynamic_client_registration_request import DynamicClientRegistrationRequest
from rapidata.api_client.models.paged_result_of_clients_query_result import PagedResultOfClientsQueryResult
from rapidata.api_client.models.query_model import QueryModel

from rapidata.api_client.api_client import ApiClient, RequestSerialized
from rapidata.api_client.api_response import ApiResponse
from rapidata.api_client.rest import RESTResponseType


class ClientApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def client_client_id_delete(
        self,
        client_id: Annotated[StrictStr, Field(description="The id of the client to delete.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Deletes a customers' client.


        :param client_id: The id of the client to delete. (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_client_id_delete_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def client_client_id_delete_with_http_info(
        self,
        client_id: Annotated[StrictStr, Field(description="The id of the client to delete.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Deletes a customers' client.


        :param client_id: The id of the client to delete. (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_client_id_delete_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def client_client_id_delete_without_preload_content(
        self,
        client_id: Annotated[StrictStr, Field(description="The id of the client to delete.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Deletes a customers' client.


        :param client_id: The id of the client to delete. (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_client_id_delete_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _client_client_id_delete_serialize(
        self,
        client_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if client_id is not None:
            _path_params['clientId'] = client_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'OAuth2', 
            'OpenIdConnect', 
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/client/{clientId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def client_client_id_get(
        self,
        client_id: Annotated[StrictStr, Field(description="The ID of the client to retrieve.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ClientModel:
        """Gets a specific client by its ID.


        :param client_id: The ID of the client to retrieve. (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientModel",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def client_client_id_get_with_http_info(
        self,
        client_id: Annotated[StrictStr, Field(description="The ID of the client to retrieve.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ClientModel]:
        """Gets a specific client by its ID.


        :param client_id: The ID of the client to retrieve. (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientModel",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def client_client_id_get_without_preload_content(
        self,
        client_id: Annotated[StrictStr, Field(description="The ID of the client to retrieve.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Gets a specific client by its ID.


        :param client_id: The ID of the client to retrieve. (required)
        :type client_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_client_id_get_serialize(
            client_id=client_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ClientModel",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _client_client_id_get_serialize(
        self,
        client_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if client_id is not None:
            _path_params['clientId'] = client_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'text/plain', 
                    'application/json', 
                    'text/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'OAuth2', 
            'OpenIdConnect', 
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/client/{clientId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def client_post(
        self,
        create_client_model: Annotated[CreateClientModel, Field(description="The model for creating a new client.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CreateCustomerClientResult:
        """Creates a new client for the current customer.


        :param create_client_model: The model for creating a new client. (required)
        :type create_client_model: CreateClientModel
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_post_serialize(
            create_client_model=create_client_model,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateCustomerClientResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def client_post_with_http_info(
        self,
        create_client_model: Annotated[CreateClientModel, Field(description="The model for creating a new client.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CreateCustomerClientResult]:
        """Creates a new client for the current customer.


        :param create_client_model: The model for creating a new client. (required)
        :type create_client_model: CreateClientModel
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_post_serialize(
            create_client_model=create_client_model,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateCustomerClientResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def client_post_without_preload_content(
        self,
        create_client_model: Annotated[CreateClientModel, Field(description="The model for creating a new client.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Creates a new client for the current customer.


        :param create_client_model: The model for creating a new client. (required)
        :type create_client_model: CreateClientModel
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_post_serialize(
            create_client_model=create_client_model,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateCustomerClientResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _client_post_serialize(
        self,
        create_client_model,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_client_model is not None:
            _body_params = create_client_model


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'text/plain', 
                    'application/json', 
                    'text/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'text/json', 
                        'application/*+json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'OAuth2', 
            'OpenIdConnect', 
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/client',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def client_register_post(
        self,
        dynamic_client_registration_request: DynamicClientRegistrationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ClientModel:
        """Registers a new client dynamically.

        The implementation of this method follows the OpenID Connect Dynamic Client Registration.

        :param dynamic_client_registration_request: (required)
        :type dynamic_client_registration_request: DynamicClientRegistrationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_register_post_serialize(
            dynamic_client_registration_request=dynamic_client_registration_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "ClientModel",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def client_register_post_with_http_info(
        self,
        dynamic_client_registration_request: DynamicClientRegistrationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ClientModel]:
        """Registers a new client dynamically.

        The implementation of this method follows the OpenID Connect Dynamic Client Registration.

        :param dynamic_client_registration_request: (required)
        :type dynamic_client_registration_request: DynamicClientRegistrationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_register_post_serialize(
            dynamic_client_registration_request=dynamic_client_registration_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "ClientModel",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def client_register_post_without_preload_content(
        self,
        dynamic_client_registration_request: DynamicClientRegistrationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Registers a new client dynamically.

        The implementation of this method follows the OpenID Connect Dynamic Client Registration.

        :param dynamic_client_registration_request: (required)
        :type dynamic_client_registration_request: DynamicClientRegistrationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._client_register_post_serialize(
            dynamic_client_registration_request=dynamic_client_registration_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "ClientModel",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _client_register_post_serialize(
        self,
        dynamic_client_registration_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if dynamic_client_registration_request is not None:
            _body_params = dynamic_client_registration_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'text/plain', 
                    'application/json', 
                    'text/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'text/json', 
                        'application/*+json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'OAuth2', 
            'OpenIdConnect', 
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/client/register',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def clients_get(
        self,
        request: Optional[QueryModel] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PagedResultOfClientsQueryResult:
        """Queries the clients for the current customer.

        A client allows a customer to authenticate with the APIs without using their own credentials.  This is useful for creating service accounts or other automated processes,  as when using the Rapidata Python SDK.

        :param request:
        :type request: QueryModel
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._clients_get_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PagedResultOfClientsQueryResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def clients_get_with_http_info(
        self,
        request: Optional[QueryModel] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PagedResultOfClientsQueryResult]:
        """Queries the clients for the current customer.

        A client allows a customer to authenticate with the APIs without using their own credentials.  This is useful for creating service accounts or other automated processes,  as when using the Rapidata Python SDK.

        :param request:
        :type request: QueryModel
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._clients_get_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PagedResultOfClientsQueryResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def clients_get_without_preload_content(
        self,
        request: Optional[QueryModel] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Queries the clients for the current customer.

        A client allows a customer to authenticate with the APIs without using their own credentials.  This is useful for creating service accounts or other automated processes,  as when using the Rapidata Python SDK.

        :param request:
        :type request: QueryModel
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._clients_get_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PagedResultOfClientsQueryResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _clients_get_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if request is not None:
            
            _query_params.append(('request', request))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'text/plain', 
                    'application/json', 
                    'text/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'OAuth2', 
            'OpenIdConnect', 
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/clients',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from rapidata.api_client.api.campaign_api import CampaignApi
    from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient


class CampaignService:
    def __init__(self, api_client: RapidataApiClient) -> None:
        self._api_client = api_client
        self._campaign_api: CampaignApi | None = None

    @property
    def campaign_api(self) -> CampaignApi:
        if self._campaign_api is None:
            from rapidata.api_client.api.campaign_api import CampaignApi
            self._campaign_api = CampaignApi(self._api_client)
        return self._campaign_api



from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from rapidata.api_client.api.validation_set_api import ValidationSetApi
    from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient


class ValidationService:
    def __init__(self, api_client: RapidataApiClient) -> None:
        self._api_client = api_client
        self._validation_api: ValidationSetApi | None = None

    @property
    def validation_api(self) -> ValidationSetApi:
        if self._validation_api is None:
            from rapidata.api_client.api.validation_set_api import ValidationSetApi
            self._validation_api = ValidationSetApi(self._api_client)
        return self._validation_api



from .models import TranslationBehaviourOptions
from .alert_on_fast_response import AlertOnFastResponseSetting, AlertOnFastResponse
from .translation_behaviour import TranslationBehaviourSetting, TranslationBehaviour
from .free_text_minimum_characters import FreeTextMinimumCharactersSetting, FreeTextMinimumCharacters
from .no_shuffle import NoShuffleSetting, NoShuffle
from .play_video_until_the_end import PlayVideoUntilTheEndSetting, PlayVideoUntilTheEnd
from .custom_setting import CustomSetting
from ._rapidata_setting import RapidataSetting
from .allow_neither_both import AllowNeitherBothSetting, AllowNeitherBoth
from .swap_context_instruction import SwapContextInstructionSetting, SwapContextInstruction
from .mute_video import MuteVideoSetting, MuteVideo
from .rapidata_settings import RapidataSettings



from rapidata.rapidata_client.selection.demographic_selection import DemographicSelection
from rapidata.rapidata_client.selection.labeling_selection import LabelingSelection
from rapidata.rapidata_client.selection.validation_selection import ValidationSelection
from rapidata.rapidata_client.selection.conditional_validation_selection import ConditionalValidationSelection
from rapidata.rapidata_client.selection.capped_selection import CappedSelection
from rapidata.rapidata_client.selection.shuffling_selection import ShufflingSelection


class RapidataSelections:
    """RapidataSelections Classes

    Selections are used to define what type of tasks and in what order they are shown to the user.
    All selections combined are called a "Session". A session can contain multiple tasks of different types of tasks.
    As an example, a session might be 1 validation task, 2 labeling tasks.

    Attributes:
        Labeling (LabelingSelection): Decides how many actual datapoints you want to show per session.
        Validation (ValidationSelection): Decides how many validation rapids you want to show per session.
        ConditionalValidation (ConditionalValidationSelection): Probabilistically decides how many validation rapids you want to show per session based on the user score.
        Demographic (DemographicSelection): Decides if and how many demographic questions you want to show per session.
        Capped (CappedSelection): Takes in different selections and caps the amount of rapids that can be shown.
        Shuffling (ShufflingSelection): Shuffles the selections provided in the list.

    Example:
        ```python
        from rapidata import LabelingSelection, ValidationSelection
        selections=[ValidationSelection("your-validation-set-id", 1),
                    LabelingSelection(2)]
        ```

        This will require annotators to complete one validation task followed by two labeling tasks.
    """

    Labeling = LabelingSelection
    Validation = ValidationSelection
    ConditionalValidation = ConditionalValidationSelection
    Demographic = DemographicSelection
    Capped = CappedSelection
    Shuffling = ShufflingSelection

    def __str__(self) -> str:
        return f"RapidataSelections(Labeling={self.Labeling}, Validation={self.Validation}, ConditionalValidation={self.ConditionalValidation}, Demographic={self.Demographic}, Capped={self.Capped}, Shuffling={self.Shuffling})"

    def __repr__(self) -> str:
        return self.__str__()



from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from rapidata.api_client.api.workflow_api import WorkflowApi
    from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient


class WorkflowService:
    def __init__(self, api_client: RapidataApiClient) -> None:
        self._api_client = api_client
        self._workflow_api: WorkflowApi | None = None

    @property
    def workflow_api(self) -> WorkflowApi:
        if self._workflow_api is None:
            from rapidata.api_client.api.workflow_api import WorkflowApi
            self._workflow_api = WorkflowApi(self._api_client)
        return self._workflow_api



from __future__ import annotations

import warnings

from rapidata.rapidata_client.settings.models.translation_behaviour_options import (
    TranslationBehaviourOptions,
)
from rapidata.rapidata_client.settings._rapidata_setting import RapidataSetting


class TranslationBehaviourSetting(RapidataSetting):
    """
    Defines what's the behaviour of the translation in the UI.
    Will not translate text datapoints or sentences.

    Args:
        value (TranslationBehaviourOptions): The translation behaviour.
    """

    def __init__(self, value: TranslationBehaviourOptions):
        if not isinstance(value, TranslationBehaviourOptions):
            raise ValueError("The value must be a TranslationBehaviourOptions.")

        super().__init__(key="translation_behaviour", value=value.value)


class TranslationBehaviour(TranslationBehaviourSetting):
    """Deprecated: Use :class:`TranslationBehaviourSetting` instead."""

    def __init__(self, *args, **kwargs):
        warnings.warn(
            "TranslationBehaviour is deprecated, use TranslationBehaviourSetting instead",
            DeprecationWarning,
            stacklevel=2,
        )
        super().__init__(*args, **kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from rapidata.api_client.api.order_api import OrderApi
    from rapidata.api_client.api.job_api import JobApi
    from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient


class OrderService:
    def __init__(self, api_client: RapidataApiClient) -> None:
        self._api_client = api_client
        self._order_api: OrderApi | None = None
        self._job_api: JobApi | None = None

    @property
    def order_api(self) -> OrderApi:
        if self._order_api is None:
            from rapidata.api_client.api.order_api import OrderApi
            self._order_api = OrderApi(self._api_client)
        return self._order_api

    @property
    def job_api(self) -> JobApi:
        if self._job_api is None:
            from rapidata.api_client.api.job_api import JobApi
            self._job_api = JobApi(self._api_client)
        return self._job_api



from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from rapidata.api_client.api.pipeline_api import PipelineApi
    from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient


class PipelineService:
    def __init__(self, api_client: RapidataApiClient) -> None:
        self._api_client = api_client
        self._pipeline_api: PipelineApi | None = None

    @property
    def pipeline_api(self) -> PipelineApi:
        if self._pipeline_api is None:
            from rapidata.api_client.api.pipeline_api import PipelineApi
            self._pipeline_api = PipelineApi(self._api_client)
        return self._pipeline_api



from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from rapidata.api_client.api.audience_api import AudienceApi
    from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient


class AudienceService:
    def __init__(self, api_client: RapidataApiClient) -> None:
        self._api_client = api_client
        self._audience_api: AudienceApi | None = None

    @property
    def audience_api(self) -> AudienceApi:
        if self._audience_api is None:
            from rapidata.api_client.api.audience_api import AudienceApi
            self._audience_api = AudienceApi(self._api_client)
        return self._audience_api



from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from rapidata.api_client.api.asset_api import AssetApi
    from rapidata.api_client.api.batch_upload_api import BatchUploadApi
    from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient


class AssetService:
    def __init__(self, api_client: RapidataApiClient) -> None:
        self._api_client = api_client
        self._asset_api: AssetApi | None = None
        self._batch_upload_api: BatchUploadApi | None = None

    @property
    def asset_api(self) -> AssetApi:
        if self._asset_api is None:
            from rapidata.api_client.api.asset_api import AssetApi
            self._asset_api = AssetApi(self._api_client)
        return self._asset_api

    @property
    def batch_upload_api(self) -> BatchUploadApi:
        if self._batch_upload_api is None:
            from rapidata.api_client.api.batch_upload_api import BatchUploadApi
            self._batch_upload_api = BatchUploadApi(self._api_client)
        return self._batch_upload_api
